@@ -19,8 +19,11 @@ function(libname, pkgname)
  else dll <- try(library.dynam("RGtk2", pkgname, libname),
                  silent = getOption("verbose"))
  if (is.character(dll)) {
-   message("Failed to load RGtk2 dynamic library, attempting to install it.")
+   warning("Failed to load RGtk2 dynamic library, attempting to install it.",
+           call. = FALSE)
    .install_system_dependencies()
+   if (.Platform$OS.type == "windows") # just try to load the package again
+     .onLoad(libname, pkgname)
    return()
  }
    
@@ -30,15 +33,8 @@ function(libname, pkgname)
  else
   args <- as.character(.gtkArgs)
 
- #if ("REventLoop" %in% rownames(installed.packages())) {
- #    library(REventLoop)
- #    eventLoop(REventLoop("R_Gtk2EventLoop"))
- #    runEventLoop()
- #} else
  if(!(gtkInit(args))) {
-   message("R session is headless; GTK+ not initialized.")
-   if (length(grep("darwin", R.version$platform)))
-     message("Please try running R inside an X11 terminal.")
+   .init_failed()
  }
 
  .initClasses()
@@ -115,3 +111,7 @@ function(libname, pkgname)
           " installed and that it is on your PATH environment variable")
   message("IN ANY CASE, RESTART R BEFORE TRYING TO LOAD THE PACKAGE AGAIN")
 }
+
+.init_failed <- function() {
+  message("R session is headless; GTK+ not initialized.")
+}
